import 'package:cpt_main/modules/visitor/vm/visitor_view_model.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:cs_resources/theme/theme_notifier.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:plugin_basic/provider/user_config/user_config_service.dart';
import 'package:widgets/dialog/app_default_dialog.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_load_image.dart';

@RoutePage()
class VisitorPage extends HookConsumerWidget {
  const VisitorPage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final _userService = UserConfigService.getInstance(ref: ref);
    final _userConfig = UserConfigService.getState(ref: ref);
    final _viewModel = ref.watch(visitorViewModelProvider.notifier);

    return Scaffold(
      appBar: AppBar(title: Text("Visitor")),
      backgroundColor: context.appColors.backgroundDefault,
      body: Center(
        child: Column(
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceAround,
              children: [
                Text("当前的用户:${_userConfig.userName}"),
                ElevatedButton(
                  onPressed: () {
                    _userService.setUserInfo("张三");
                  },
                  child: Text(
                    '修改用户信息',
                  ),
                ),
              ],
            ).marginOnly(top: 10),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceAround,
              children: [
                ElevatedButton(
                  onPressed: () {
                    _viewModel.fetchServerTime();
                  },
                  child: Text('网络请求'),
                ),
                ElevatedButton(
                  onPressed: () {},
                  child: Text('吐司/气泡'),
                ),
                ElevatedButton(
                  onPressed: () {},
                  child: Text('成功/失败通知'),
                ),
              ],
            ).marginOnly(top: 10),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceAround,
              children: [
                ElevatedButton(
                  onPressed: () {},
                  child: Text('弹窗'),
                ),
                ElevatedButton(
                  onPressed: () {},
                  child: Text('时间选择'),
                ),
                ElevatedButton(
                  onPressed: () {},
                  child: Text('条件选择'),
                ),
              ],
            ).marginOnly(top: 10),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceAround,
              children: [
                ElevatedButton(
                  onPressed: () {},
                  child: Text('相机'),
                ),
                ElevatedButton(
                  onPressed: () {},
                  child: Text('相册'),
                ),
                ElevatedButton(
                  onPressed: () {},
                  child: Text('App动态权限'),
                ),
              ],
            ).marginOnly(top: 10),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceAround,
              children: [
                ElevatedButton(
                  onPressed: () {},
                  child: Text('App的沙盒路径'),
                ),
                ElevatedButton(
                  onPressed: () {},
                  child: Text('缓存用法'),
                ),
                ElevatedButton(
                  onPressed: () {},
                  child: Text('图片预览'),
                ),
              ],
            ).marginOnly(top: 10),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceAround,
              children: [
                ElevatedButton(
                  onPressed: () {},
                  child: Text('图片加载'),
                ),
                MyLoadImage("https://pic.quanjing.com/cz/8s/QJ8856274343.jpg@%21794ws", width: 80, height: 80),
                ElevatedButton(
                  onPressed: () {},
                  child: Text('图片预览'),
                ),
              ],
            ).marginOnly(top: 10),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceAround,
              children: [
                ElevatedButton(
                  onPressed: () {
                    ref.read(themeProvider.notifier).toggleTheme();
                  },
                  child: Text('手动切换主题'),
                  style: ButtonStyle(
                    backgroundColor: WidgetStateProperty.all<Color>(context.appColors.btnBgDefault),
                    // 设置按钮的背景颜色
                    foregroundColor: WidgetStateProperty.all<Color>(Colors.white),
                    // 设置按钮文字的颜色
                    shadowColor: WidgetStateProperty.all<Color>(context.appColors.btnBgDefault),
                    // 按钮阴影颜色
                    elevation: WidgetStateProperty.all<double>(5),
                    // 按钮阴影的高度
                    shape: WidgetStateProperty.all<RoundedRectangleBorder>(
                      RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(30), // 圆角边框
                      ),
                    ),
                  ),
                ),
                ElevatedButton(
                  onPressed: () {
                    ref.read(themeProvider.notifier).followSystemTheme();
                  },
                  child: Text('跟随系统主题'),
                  style: ButtonStyle(
                    backgroundColor: WidgetStateProperty.all<Color>(context.appColors.btnBgDefault),
                    // 设置按钮的背景颜色
                    foregroundColor: WidgetStateProperty.all<Color>(Colors.white),
                    // 设置按钮文字的颜色
                    shadowColor: WidgetStateProperty.all<Color>(context.appColors.btnBgDefault),
                    // 按钮阴影颜色
                    elevation: WidgetStateProperty.all<double>(5),
                    // 按钮阴影的高度
                    shape: WidgetStateProperty.all<RoundedRectangleBorder>(
                      RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(30), // 圆角边框
                      ),
                    ),
                  ),
                ),
              ],
            ).marginOnly(top: 10),
          ],
        ),
      ),
    );
  }
}
